@@ -1,6 +1,6 @@
 # Release information about Select-Shuttle
 
-version = "0.91"
+version = "0.92"
 
 description = """The SelectShuttle widget provides a mechanism for selecting
 multiple values from a list of values by allowing the user to move items
@@ -13,9 +13,7 @@ to use this widget in your code."""
 author = "Jorge Godoy"
 
 email = "jgodoy@gmail.com"
-# copyright = "Vintage 2006 - a good year indeed"
 
-# if it's open source, you might want to specify these
 url = "http://www.g2ctech.com/"
-download_url = "http://www.g2ctech.com/widgets/Select_Shuttle-0.91-py2.4.egg"
+download_url = "http://www.g2ctech.com/widgets/Select_Shuttle-%s-py2.4.egg" % version
 license = "MIT"
